##===============================================================================
## Objetivos
##===============================================================================
## Exemplificar, mediante uso do R, a anlise de varincia de experimentos
## fatoriais com fatores qualitativos e interao significativa.
##
## Experimento: ensaio de Espcie e Manejo (3^1 x 4^1) montado
## em DBC com 4 repeties.
##
## So apresentados duas alternativas de anlise:
## - Teste de Tukey
## - Anlise de contrastes
##===============================================================================
## Correo: J.C.Faria - 2023-12-08 12:46:16
##===============================================================================

#. Leitura  e ajuste dos dados
dad <- read.table('ef.txt',
                  colClasses=c('factor',
                               'factor',
                               'factor',
                               'integer'),
                  header=TRUE)
                  
## Estrutura dos dados
str(dad)

## Alteraes necessrias para ANOVA: transformao de inteiros em fatores
## No  mais necessrio: mais fcil informar adequadamente o argumento colClasses na read.table!
#dad$esp <- factor(dad$esp)
#dad$man <- factor(dad$man)
#dad$blo <- factor(dad$blo)
#str(dad)

#. Interaction plot
## Grficos que permitem verificar visualmente possveis interaces
par(mfrow=c(2,1))  
with(dad,
     interaction.plot(esp, man, pro,
                      xlab='ESPCIE',
                      ylab='Pro',
                      col='blue3',
                      lwd=2))

with(dad,
     interaction.plot(man, esp, pro,
                      xlab='MANEJO',
                      ylab='Pro', 
                      col='green3',
                      lwd=2))

#... Observar indicao visual de interao entre ESPCIE e MANEJO!

#. ANOVA bsica
av_0 <- aov(pro ~ blo + esp + man + esp*man,
            data=dad)

summary(av_0)

## Observar que a interao entre ESPCIE e MANEJO  no significativa a 5% de probabilidade pelo teste F!
## Nesses casos - resultados divergentes entre anlise visual e ANOVA - 
##  necessrio aprofundar a anlise via testes de comparao de mdias 
## (ou contrastes) para verificar se realmente no existe interao.
## O efeito da interao pode ser pequeno e estar diludo na ANOVA.
## Isto  muito comum em experimentos fatoriais, principlamente nos casos onde o pvalor
## associado a interao est prximo do limite do erro tipo I considerado.

#. Testes de comparao de mdias
#.. Estudo dos efeitos principais
## Se assumir que realmente no existe interao: a identificao dos melhores
## nveis dos fatores - efeitos principais - pode ser feito conforme abaixo:
library(TukeyC)

## ESPCIE
tk1 <- TukeyC(x=av_0,
              which='esp')
summary(tk1)

## MANEJO
tk2 <- TukeyC(x=av_0,
              which='man')
summary(tk2)

#.. Estudo da interao
#... Estudo de MANEJO dentro de ESPCIE (esp/man)
## Nested: esp1/man
ntk1 <- TukeyC(av_0,
               which='esp:man',
               fl1=1)
summary(ntk1)

## Nested: esp2/man
ntk2 <- TukeyC(av_0,
               which='esp:man',
               fl1=2)
summary(ntk2)

## Nested: esp3/man
ntk3 <- TukeyC(av_0,
               which='esp:man',
               fl1=3)
summary(ntk3)
##------------------------------------------------------------------------------------------
## Observa-se alterao no padro das respostas de esp:man!
## Contrariando a ANOVA preliminar,
## observa-se interao significativa pelo teste de Tuckey ao nvel de 5% de probabilidade!
##------------------------------------------------------------------------------------------


#... Estudo de ESPCIE dentro de MANEJO (man/esp)
## Nested: man1/esp
ntk11 <- TukeyC(av_0,
                which='man:esp',
                fl1=1)
summary(ntk11)

## Nested: man2/esp
ntk12 <- TukeyC(av_0,
                which='man:esp',
                fl1=2)
summary(ntk12)

## Nested: man3/esp
ntk13 <- TukeyC(av_0,
                which='man:esp',
                fl1=3)
summary(ntk13)

## Nested: man4/esp
ntk14 <- TukeyC(av_0,
                which='man:esp',
                fl1=4)
summary(ntk14)
##------------------------------------------------------------------------------------------
## Observa-se alterao no padro das respostas de man:esp!
## Contrariando a ANOVA preliminar,
## observa-se interao significativa pelo teste de Tuckey ao nvel de 5% de probabilidade!
##------------------------------------------------------------------------------------------

#. Anlise via contrastes ortogonais
#... Matriz de contrastes: ESPCIE
                                   #e1  e2  e3
mce <- rbind('_e1 vs. (e2, e3)' = c( 2, -1, -1),
             '_e2 vs. e3'       = c( 0,  1, -1))


#... Matriz de contrastes: MANEJO
                                       #m1  m2  m3  m4
mcm <- rbind('_m1 vs. (m2, m3, m4)' = c( 3, -1, -1, -1),
             '_m4 vs. (m2, m3)'     = c( 0, -1, -1,  2),
             '_m2 vs. m3'           = c( 0,  1, -1,  0))

## Aninhamento dos efeitos de MANEJO e da Interao em esp:man
## Necessrio aninhar os efeitos para o desdobramento correto em contrastes ortogonais
## Observar:
## - argumento 'contrasts' conjuntamente com a funo 'summary' com o argumento 'split'
## - mudana no modelo em relao ao anterior (av1): aninhamento do efeitos de MANEJO
##   juntamente com a interao esp/man.

library('gmodels') # O pavote gmodels fornece a funo "make.contrasts" usada abaixo

#.. ANOVA com aninhamento de efeitos (esp/man)
av_1 <- aov(pro ~ blo + esp + esp/man,
            data=dad,
            contrasts=list('esp'=make.contrasts(mce),
                           'man'=make.contrasts(mcm)))

## Comparar com av_0
summary(av_1)

## Fundamental para construir o constrastes abaixo
effects(av_1)[7:15]
coef(av_1)[7:15]

## Anlise preliminar no efeito de MANEJO dentro de cada nvel de ESPCIE
summary(av_1,
        split=list('esp:man'=list('e1/m'=c(1, 4, 7),
                                  'e2/m'=c(2, 5, 8),
                                  'e3/m'=c(3, 6, 9))))

## Observa-se que dentro de cada nvel de ESPCIE existe pelo menos um contraste entre os
## nveis de MANEJO estatisticamente diferente de zero ao nvel de 5% de probabilidade pelo teste F.

## Detalhando o estudo de MANEJO dentro de ESPCIE: esp/man
sm_1 <- summary(av_1,
                split=list('esp:man'=list('e1/m*'= c(1, 4, 7),
                                          'e1/m1 vs. (m2,m3,m4)'= 1,
                                          'e1/m4 vs. (m2,m3)'   = 4,
                                          'e1/m2 vs. m3'        = 7,

                                          'e2/m*'= c(2, 5, 8),
                                          'e2/m1 vs. (m2,m3,m4)'= 2,
                                          'e2/m4 vs. (m2,m3)'   = 5,
                                          'e2/m2 vs. m3'        = 8,

                                          'e3/m*'= c(3, 6, 9),
                                          'e3/m1 vs. (m2,m3,m4)'= 3,
                                          'e3/m4 vs. (m2,m3)'   = 6,
                                          'e3/m2 vs. m3'        = 9)))

sm_1
#------------------------------------------------------------------------
#                                Df Sum Sq Mean Sq F value   Pr(>F)
#------------------------------------------------------------------------
#blo                              3  82273   27424   3.898 0.017295 *
#esp                              2 344425  172212  24.475 3.03e-07 ***
#------------------------------------------------------------------------
#esp:man                          9 593454   65939   9.371 6.76e-07 ***
#------------------------------------------------------------------------
#  esp:man: e1/m*                (3) 172957   57652   8.194 0.000326 ***
#------------------------------------------------------------------------
#  esp:man: e1/m1 vs. (m2,m3,m4)  1 142028  142028  20.185 8.15e-05 ***
#  esp:man: e1/m4 vs. (m2,m3)     1  30817   30817   4.380 0.044139 *
#  esp:man: e1/m2 vs. m3          1    113     113   0.016 0.900146
#------------------------------------------------------------------------
#  esp:man: e2/m*                (3) 181402   60467   8.594 0.000234 ***
#------------------------------------------------------------------------
#  esp:man: e2/m1 vs. (m2,m3,m4)  1 156180  156180  22.196 4.31e-05 ***
#  esp:man: e2/m4 vs. (m2,m3)     1  25220   25220   3.584 0.067125 .
#  esp:man: e2/m2 vs. m3          1      2       2   0.000 0.986650
#------------------------------------------------------------------------
#  esp:man: e3/m*                (3) 239095   79698  11.327 2.90e-05 ***
#------------------------------------------------------------------------
#  esp:man: e3/m1 vs. (m2,m3,m4)  1 137602  137602  19.556 0.000100 ***
#  esp:man: e3/m4 vs. (m2,m3)     1   2481    2481   0.353 0.556720
#  esp:man: e3/m2 vs. m3          1  99012   99012  14.072 0.000678 ***
#------------------------------------------------------------------------
#Residuals                       33 232198    7036
#---

##----------------------------------------------------------------
## Observa-se interao significativa pela anlise de contrastes!
##----------------------------------------------------------------


#.. ANOVA com aninhamento de efeitos (man/esp)
av_2 <- aov(pro ~ blo + man + man/esp,
            data=dad,
            contrasts=list('esp'=make.contrasts(mce),
                           'man'=make.contrasts(mcm)))

summary(av_2)

effects(av_2)[8:15]
coef(av_2)[8:15]

# Anlise preliminar no efeito de ESPCIE dentro de cada nvel de MANEJO
summary(av_2,
        split=list('man:esp'=list('m1/e'= c(1, 5),
                                  'm2/e'= c(2, 6),
                                  'm3/e'= c(3, 7),
                                  'm4/e'= c(4, 8))))

## Observa-se que dentro dos nveis de MANEJO: 1, 2 e 4, existe pelo menos um contraste
## dos nveis de ESPCIE estatisticamente diferente de zero ao nvel de 5% de probabilidade pelo teste F.
## Dentro do nvel 3 de ESPCIE todos os contrastes entre os nveis de MANEJO so estatisticamente nulos
## ao nvel de 5% de probabilidade pelo teste F.

## man/esp
sm_2 <- summary(av_2,
                split=list('man:esp'=list('m1/e*'= c(1, 5),
                                          'm1/e3 vs. (e2,e1)'= 1,
                                          'm1/e2 vs. e1'     = 5,

                                          'm2/e*'= c(2, 6),
                                          'm2/e3 vs. (e2,e1)'= 2,
                                          'm2/e2 vs. e1'     = 6,

                                          'm3/e*'= c(3, 7),
                                          'm3/e3 vs. (e2,e1)'= 3,
                                          'm3/e2 vs. e1'     = 7,

                                          'm4/e*'= c(4, 8),
                                          'm4/e3 vs. (e2,e1)'= 4,
                                          'm4/e2 vs. e1'     = 8)))

sm_2
#---------------------------------------------------------------------
#                             Df Sum Sq Mean Sq F value   Pr(>F)
#---------------------------------------------------------------------
#blo                           3  82273   27424   3.898 0.017295 *
#man                           3 515787  171929  24.435 1.63e-08 ***
#---------------------------------------------------------------------
#man:esp                      (8) 422092   52761   7.498 1.17e-05 ***
#---------------------------------------------------------------------
#  man:esp: m1/e*             (2)  81590   40795   5.798 0.006953 **
#---------------------------------------------------------------------
#  man:esp: m1/e3 vs. (e2,e1)  1  40262   40262   5.722 0.022607 *
#  man:esp: m1/e2 vs. e1       1  41328   41328   5.874 0.021016 *
#---------------------------------------------------------------------
#  man:esp: m2/e*             (2) 193329   96665  13.738 4.56e-05 ***
#---------------------------------------------------------------------
#  man:esp: m2/e3 vs. (e2,e1)  1  72051   72051  10.240 0.003033 **
#  man:esp: m2/e2 vs. e1       1 121278  121278  17.236 0.000218 ***
#---------------------------------------------------------------------
#  man:esp: m3/e*             (2)   6655    3328   0.473 0.627340
#---------------------------------------------------------------------
#  man:esp: m3/e3 vs. (e2,e1)  1   5430    5430   0.772 0.386038
#  man:esp: m3/e2 vs. e1       1   1225    1225   0.174 0.679183
#---------------------------------------------------------------------
#  man:esp: m4/e*             (2) 140517   70259   9.985 0.000406 ***
#---------------------------------------------------------------------
#  man:esp: m4/e3 vs. (e2,e1)  1  58707   58707   8.343 0.006786 **
#  man:esp: m4/e2 vs. e1       1  81810   81810  11.627 0.001732 **
#---------------------------------------------------------------------
#Residuals                    33 232198    7036
#---

##----------------------------------------------------------------
## Observa-se interao significativa pela anlise de contrastes!
##----------------------------------------------------------------
